pub struct NetworkConnection { /* private fields */ }Expand description
Represents an active network connection to a remote Raft node. Handles serialization and deserialization of Raft messages over gRPC.
Implementations
Sourceimpl NetworkConnection
impl NetworkConnection
Sourcepub fn new(target_node: <TypeConfig as RaftTypeConfig>::Node) -> Self
pub fn new(target_node: <TypeConfig as RaftTypeConfig>::Node) -> Self
Creates a new NetworkConnection with the provided gRPC client.