pub struct AppendEntriesRequest {
pub vote: Option<Vote>,
pub prev_log_id: Option<LogId>,
pub entries: Vec<Entry>,
pub leader_commit: Option<LogId>,
}Fields
vote: Option<Vote>The leader’s vote, used to identify the leader, and must be committed.
prev_log_id: Option<LogId>The previous log id the leader has sent to the follower.
entries: Vec<Entry>The entries to be appended to the follower’s log.
leader_commit: Option<LogId>The leader’s last committed log id.