AppendEntriesResponse

Struct AppendEntriesResponse 

pub struct AppendEntriesResponse {
    pub rejected_by: Option<Vote>,
    pub conflict: bool,
    pub last_log_id: Option<LogId>,
}

Fields

rejected_by: Option<Vote>

If not None, the follower rejected the AppendEntries request due to having a higher vote. All other fields are valid only when this field is None.

conflict: bool

The follower accepts this AppendEntries request’s vote, but the prev_log_id conflicts with the follower’s log. The leader should retry with a smaller prev_log_id that matches the follower’s log.

For unary AppendEntries, last_log_id is not used for conflicts. For StreamAppend (pipeline replication), last_log_id carries the conflict log id.

last_log_id: Option<LogId>

If conflict = false, the last log id the follower accepted from this request:

  • None: all input entries were accepted and persisted.
  • Some: partial success; only entries up to and including this id were accepted.

If conflict = true in StreamAppend, this is the conflict log id.