pub struct LeaderId {
pub term: u64,
pub node_id: u64,
}Expand description
LeaderId represents the leader identifier in Raft.
Fields
term: u64node_id: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for LeaderId
impl<'de> Deserialize<'de> for LeaderId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for LeaderId
impl Message for LeaderId
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialOrd<u64> for LeaderId
impl PartialOrd<u64> for LeaderId
Sourceimpl PartialOrd for LeaderId
Implements PartialOrd for LeaderId to enforce the standard Raft behavior of
at most one leader per term.
impl PartialOrd for LeaderId
Implements PartialOrd for LeaderId to enforce the standard Raft behavior of at most one leader per term.
In standard Raft, each term can have at most one leader. This is enforced by making leader IDs with the same term incomparable (returning None), unless they refer to the same node.
This differs from the PartialOrd default implementation which would
allow multiple leaders in the same term by comparing node IDs.
Sourceimpl RaftLeaderId<TypeConfig> for LeaderId
impl RaftLeaderId<TypeConfig> for LeaderId
Sourcefn to_committed(&self) -> Self::Committed
fn to_committed(&self) -> Self::Committed
Convert this leader ID to a committed leader ID. Read more
impl Copy for LeaderId
impl Eq for LeaderId
impl StructuralPartialEq for LeaderId