pub struct Membership {
pub configs: Vec<NodeIdSet>,
pub nodes: BTreeMap<u64, Node>,
}Expand description
Membership config.
Fields
configs: Vec<NodeIdSet>Joint(includes more than one NodeIdSet) or uniform(one NodeIdSet) config.
nodes: BTreeMap<u64, Node>All of the nodes in the cluster, including voters and learners.
A node id that is included in configs is a voter, otherwise it is a learner.