pub struct SnapshotRequest {
pub payload: Option<Payload>,
}Expand description
The item of snapshot chunk stream.
The first item contains meta, including the leader vote and snapshot-meta.
Since the second item, the chunk contains the snapshot data.
Fields
payload: Option<Payload>Implementations
Sourceimpl SnapshotRequest
impl SnapshotRequest
pub fn into_meta(self) -> Option<SnapshotRequestMeta>
pub fn into_data_chunk(self) -> Option<Vec<u8>>