pub struct StateMachineData {
pub last_applied: Option<LogId>,
pub data: BTreeMap<String, String>,
pub last_membership_log_id: Option<LogId>,
pub last_membership: Option<Membership>,
}Expand description
All the data in a state machine, including user defined data and membership data.
Fields
last_applied: Option<LogId>The last log id that has been applied to the state machine.
data: BTreeMap<String, String>User data in a map.
last_membership_log_id: Option<LogId>The id of the last membership config log entry that is applied.
last_membership: Option<Membership>The last membership config that is applied.