pub struct Vote {
pub leader_id: Option<LeaderId>,
pub committed: bool,
}Expand description
Vote represents the voting information in Raft leader election.
Fields
leader_id: Option<LeaderId>committed: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Vote
impl<'de> Deserialize<'de> for Vote
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for Vote
impl Message for Vote
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl RaftVote<TypeConfig> for Vote
impl RaftVote<TypeConfig> for Vote
Sourcefn from_leader_id(
leader_id: <TypeConfig as RaftTypeConfig>::LeaderId,
committed: bool,
) -> Self
fn from_leader_id( leader_id: <TypeConfig as RaftTypeConfig>::LeaderId, committed: bool, ) -> Self
Create a new vote for the specified leader with optional quorum commitment. Read more
Sourcefn leader_id(&self) -> &<TypeConfig as RaftTypeConfig>::LeaderId
fn leader_id(&self) -> &<TypeConfig as RaftTypeConfig>::LeaderId
Get a reference to this vote’s LeaderId(
RaftLeaderId implementation). Read moreSourcefn is_committed(&self) -> bool
fn is_committed(&self) -> bool
Whether this vote has been committed by a quorum. Read more
impl Copy for Vote
impl Eq for Vote
impl StructuralPartialEq for Vote