pub struct VoteRequest {
pub vote: Option<Vote>,
pub last_log_id: Option<LogId>,
}Expand description
VoteRequest represents a request for votes during leader election.
Fields
vote: Option<Vote>last_log_id: Option<LogId>Trait Implementations
Sourceimpl Clone for VoteRequest
impl Clone for VoteRequest
Sourcefn clone(&self) -> VoteRequest
fn clone(&self) -> VoteRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoteRequest
impl Debug for VoteRequest
Sourceimpl Default for VoteRequest
impl Default for VoteRequest
Sourceimpl From<VoteRequest<TypeConfig>> for VoteRequest
impl From<VoteRequest<TypeConfig>> for VoteRequest
Sourcefn from(vote_req: VoteRequest<TypeConfig>) -> Self
fn from(vote_req: VoteRequest<TypeConfig>) -> Self
Converts to this type from the input type.
Sourceimpl Hash for VoteRequest
impl Hash for VoteRequest
Sourceimpl Message for VoteRequest
impl Message for VoteRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VoteRequest
impl PartialEq for VoteRequest
Sourceimpl TryFrom<VoteRequest> for VoteRequest<TypeConfig>
impl TryFrom<VoteRequest> for VoteRequest<TypeConfig>
Sourcetype Error = StoreError
type Error = StoreError
The type returned in the event of a conversion error.
impl Copy for VoteRequest
impl Eq for VoteRequest
impl StructuralPartialEq for VoteRequest