pub struct VoteResponse {
pub vote: Option<Vote>,
pub vote_granted: bool,
pub last_log_id: Option<LogId>,
}Expand description
VoteResponse represents the response to a vote request.
Fields
vote: Option<Vote>vote_granted: boollast_log_id: Option<LogId>Trait Implementations
Sourceimpl Clone for VoteResponse
impl Clone for VoteResponse
Sourcefn clone(&self) -> VoteResponse
fn clone(&self) -> VoteResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoteResponse
impl Debug for VoteResponse
Sourceimpl Default for VoteResponse
impl Default for VoteResponse
Sourceimpl From<VoteResponse<TypeConfig>> for VoteResponse
impl From<VoteResponse<TypeConfig>> for VoteResponse
Sourcefn from(vote_resp: VoteResponse<TypeConfig>) -> Self
fn from(vote_resp: VoteResponse<TypeConfig>) -> Self
Converts to this type from the input type.
Sourceimpl Hash for VoteResponse
impl Hash for VoteResponse
Sourceimpl Message for VoteResponse
impl Message for VoteResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VoteResponse
impl PartialEq for VoteResponse
Sourceimpl TryFrom<VoteResponse> for VoteResponse<TypeConfig>
impl TryFrom<VoteResponse> for VoteResponse<TypeConfig>
Sourcetype Error = StoreError
type Error = StoreError
The type returned in the event of a conversion error.
impl Copy for VoteResponse
impl Eq for VoteResponse
impl StructuralPartialEq for VoteResponse